@@ -1,3 +1,5 @@
+import time
+
 import six
 from functools import wraps, partial
 from inspect import isclass, ismethod
@@ -106,3 +108,13 @@ def ref_to_obj(ref):
     except Exception:
         raise LookupError('Error resolving reference %s: error looking up object' % ref)
 
+
+def time_stat(func):
+    def inner():
+        print(f'开始计时')
+        start = time.time()
+        func()
+        end = time.time()
+        print(f'耗时: {end - start}秒')
+
+    return inner
