@@ -19,3 +19,15 @@ class InfoPredictParam(BaseModel):
     sn: str = None
     # 输入文本
     text: str = None
+
+
+class OssZipDirParam(BaseModel):
+    """
+    OSS目录压缩
+    """
+    # 桶名称
+    bucket_name: str = None
+    # 待压缩对象前缀
+    object_prefix: str = None
+    # 最终输出对象名
+    dist_object_name: str = None
