@@ -1,6 +1,4 @@
-from typing import Dict
 from ..client import CeleryClient, CeleryClientHolder
-from ..common.model import Callback
 
 
 class BaseService(object):
